@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::MsgMaker::PromptUser;
-$App::SpreadRevolutionaryDate::MsgMaker::PromptUser::VERSION = '0.15';
+$App::SpreadRevolutionaryDate::MsgMaker::PromptUser::VERSION = '0.16';
 # ABSTRACT: MsgMaker class for L<App::SpreadRevolutionaryDate> to build message by prompting user
 
 use Moose;
@@ -18,6 +18,7 @@ with 'App::SpreadRevolutionaryDate::MsgMaker';
 
 use open qw(:std :encoding(UTF-8));
 use IO::Prompt::Hooked;
+use File::Spec;
 
 use Locale::TextDomain 'App-SpreadRevolutionaryDate';
 use namespace::autoclean;
@@ -32,6 +33,13 @@ has 'default' => (
 around BUILDARGS => sub {
   my ($orig, $class, %args) = @_;
 
+  # Get sure locale has .mo file
+  if ($args{locale}) {
+    my ($volume, $directory, $file) = File::Spec->splitpath(__FILE__);
+    my $locale_mo = File::Spec->catfile($directory, '..', '..', '..', 'LocaleData', $args{locale}, 'LC_MESSAGES', 'App-SpreadRevolutionaryDate.mo');
+    $args{locale} = '' unless -f $locale_mo;
+  }
+
   # Do not pass default => undef to force default in attribute definition
   delete $args{default}
     if exists $args{default} && !defined $args{default};
@@ -95,7 +103,7 @@ App::SpreadRevolutionaryDate::MsgMaker::PromptUser - MsgMaker class for L<App::S
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 METHODS
 
